# -*- perl -*-

package Bundle::HTML::EP;

$VERSION = '0.02';

1;

__END__

=head1 NAME

Bundle::HTML::EP - A bundle to install the HTML::EP package

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::HTML::EP'>

=head1 CONTENTS

DBI 1.02

Data::Dumper

Storable

URI::Escape

CGI::Cookie

Bundle::LWP

Net::SMTP

Mail::Internet 1.32

HTML::EP

=head1 DESCRIPTION

This bundle includes all that's needed to run the HTML::EP package with
your WWW server.

=cut
